@@ -84,6 +84,18 @@ class ValueBag(dict):
         ret = self[key]
         return ret if ret else default
 
+    def has_key(self, key):
+        if '.' in key:
+            keys = key.split('.')
+            s = self
+            for key in keys:
+                if not isinstance(s, dict) or not super(ValueBag, s).has_key(key):
+                    return False
+                s = s[key]
+            return True
+
+        return super(ValueBag, self).has_key(key)
+
 class _JSONEncoder(json.encoder.JSONEncoder):
     def default(self, o):
         return str(o)
@@ -144,6 +156,15 @@ if __name__ == '__main__':
             self.assertEqual(obj['foo.bar'], 2)
             self.assertEqual(obj.get('foo.bar'), 2)
             
+        def test_has_key(self):
+            obj = ValueBag()
+            obj.a.b.c = 1
+
+            self.assertTrue(obj.has_key('a'))
+            self.assertTrue(obj.has_key('a.b'))
+            self.assertTrue(obj.has_key('a.b.c'))
+            self.assertFalse(obj.has_key('d'))
+            self.assertFalse(obj.has_key('d.d'))
     
     program.unittest_main()
         
